AS5600Driver

Struct AS5600Driver 

pub struct AS5600Driver<I2C> { /* private fields */ }
Main driver for the AS5600 sensor.

Implementations

Source

impl<I2C: I2c<SevenBitAddress>> AS5600Driver<I2C>

pub fn new(i2c: I2C) -> Self

Creates a new driver instance with the default I2C address (0x36).

pub fn with_address(i2c: I2C, address: u8) -> Self

Creates a new driver instance with a custom I2C address.

pub unsafe fn danger_permanent_burn_settings( &mut self, ) -> Result<(), AS56Error<I2C::Error>>

DANGER: Permanently burns ZPOS and MPOS settings to the chip.

pub unsafe fn danger_permanent_burn_config( &mut self, ) -> Result<(), AS56Error<I2C::Error>>

DANGER: Permanently burns Configuration settings to the chip.