pub struct AS5600Driver<I2C> { /* private fields */ }Expand description
Main driver for the AS5600 sensor.
Implementations
Sourceimpl<I2C: I2c<SevenBitAddress>> AS5600Driver<I2C>
impl<I2C: I2c<SevenBitAddress>> AS5600Driver<I2C>
Sourcepub fn new(i2c: I2C) -> Self
pub fn new(i2c: I2C) -> Self
Creates a new driver instance with the default I2C address (0x36).
Sourcepub fn with_address(i2c: I2C, address: u8) -> Self
pub fn with_address(i2c: I2C, address: u8) -> Self
Creates a new driver instance with a custom I2C address.